Merge pull request #925 from victor-pavlychko/master

diff --git a/Foundation/Progress.swift b/Foundation/Progress.swift
index 3f16c2a..08c3e30 100644
--- a/Foundation/Progress.swift
+++ b/Foundation/Progress.swift
@@ -292,8 +292,8 @@
     open var pausingHandler: (() -> Void)? {
         didSet {
             guard let handler = pausingHandler else { return }
-            // If we're already cancelled, then invoke it - asynchronously
-            if isCancelled {
+            // If we're already paused, then invoke it - asynchronously
+            if isPaused {
                 DispatchQueue.global().async {
                     handler()
                 }